NormSAX: Normalize and SAX Encode a Dataset

View source: R/mainFunction.R

NormSAXR Documentation

Normalize and SAX Encode a Dataset

Description

Applies z-score normalization to the entire dataset and encodes the values using the Symbolic Aggregate approXimation (SAX) with an alphabet of size a.

Usage

NormSAX(D, a)

Arguments

D

Dataset containing numeric values.

a

Number of letters in the SAX alphabet.

Value

A data frame with the same dimensions as D, containing SAX letter encodings (characters from a to the a-th letter of the alphabet).

Examples

DS <- NormSAX(STMotif::example_dataset, 5)

STMotif documentation built on March 30, 2026, 1:06 a.m.