RankSTMotifs: Rank Spatial-Time Motifs

View source: R/mainFunction.R

RankSTMotifsR Documentation

Rank Spatial-Time Motifs

Description

Ranks the discovered motifs by computing a composite quality score that balances spatial-temporal proximity of occurrences, entropy of the SAX encoding, and quantity of occurrences.

Usage

RankSTMotifs(stmotifs)

Arguments

stmotifs

List of identified motifs (as returned by SearchSTMotifs).

Value

A list of motifs sorted by decreasing quality score. Each motif gains a rank component with dist, word, qtd, and proj values.

Examples

D  <- STMotif::example_dataset
DS <- NormSAX(STMotif::example_dataset, 5)
stmotifs <- SearchSTMotifs(D, DS, 4, 5, 4, 10, 2, 2)
rstmotifs <- RankSTMotifs(stmotifs)

STMotif documentation built on March 30, 2026, 1:06 a.m.