| STMotif-package | R Documentation |
Identifies motifs in spatial-time series using the Combined Series Approach (CSA). A motif is a previously unknown subsequence of a spatial time series with a relevant number of occurrences. The package provides functions for SAX encoding, motif discovery, ranking, and visualization.
The main workflow consists of:
NormSAX: Normalize and encode the dataset with SAX.
SearchSTMotifs: Discover motifs in spatio-temporal blocks.
RankSTMotifs: Rank motifs by quality metrics.
These three steps are wrapped in the convenience function
CSAMiningProcess.
Visualization functions:
display_motifsDataset: Heatmap with highlighted motifs.
display_motifsSTSeries: Time series plots with highlighted motifs.
Maintainer: Heraldo Borges stmotif@eic.cefet-rj.br (CEFET/RJ)
Authors:
Amin Bazaz (Polytech'Montpellier)
Esther Pacciti (INRIA/Polytech'Montpellier)
Eduardo Ogasawara (CEFET/RJ)
vignette("STMotif") for a comprehensive introduction.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.