STSADatasetAdjust: Adjust a Dataset

View source: R/mainFunction.R

STSADatasetAdjustR Documentation

Adjust a Dataset

Description

Adjusts the dimensions of a dataset so that it can be evenly divided into spatio-temporal blocks of size tb x sb.

Usage

STSADatasetAdjust(D, tb, sb)

Arguments

D

Dataset containing numeric values.

tb

Temporal block size (number of rows per block).

sb

Spatial block size (number of columns per block).

Value

Dataset with rows and columns trimmed to be divisible by tb and sb, respectively.

Examples

D <- STSADatasetAdjust(STMotif::example_dataset, 20, 12)

STMotif documentation built on March 30, 2026, 1:06 a.m.