| RankSTMotifs | R Documentation |
Ranks the discovered motifs by computing a composite quality score that balances spatial-temporal proximity of occurrences, entropy of the SAX encoding, and quantity of occurrences.
RankSTMotifs(stmotifs)
stmotifs |
List of identified motifs (as returned by
|
A list of motifs sorted by decreasing quality score. Each motif
gains a rank component with dist, word,
qtd, and proj values.
D <- STMotif::example_dataset
DS <- NormSAX(STMotif::example_dataset, 5)
stmotifs <- SearchSTMotifs(D, DS, 4, 5, 4, 10, 2, 2)
rstmotifs <- RankSTMotifs(stmotifs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.