| STSADatasetAdjust | R Documentation |
Adjusts the dimensions of a dataset so that it can be evenly divided
into spatio-temporal blocks of size tb x sb.
STSADatasetAdjust(D, tb, sb)
D |
Dataset containing numeric values. |
tb |
Temporal block size (number of rows per block). |
sb |
Spatial block size (number of columns per block). |
Dataset with rows and columns trimmed to be divisible by
tb and sb, respectively.
D <- STSADatasetAdjust(STMotif::example_dataset, 20, 12)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.