Learn R Programming

STMotif (version 2.0.2)

STSADatasetAdjust: Adjust a Dataset Adjust the dimensions of a dataset to build the blocks

Description

Adjust a Dataset Adjust the dimensions of a dataset to build the blocks

Usage

STSADatasetAdjust(D, tb, sb)

Value

Dataset adjusted to build the blocks.

Arguments

D

Dataset containing numeric values

tb

Temporal block size

sb

Spatial block size

Examples

Run this code
#Adjust a block
D <- STSADatasetAdjust(STMotif::example_dataset, 20, 12)

Run the code above in your browser using DataLab