| SearchSTMotifs | R Documentation |
Discovers motifs in the spatio-temporal blocks of the dataset, validates occurrence constraints, and groups motifs from neighboring blocks.
SearchSTMotifs(D, DS, w, a, sb, tb, si = 3, ka = 3)
D |
Dataset containing numeric values. |
DS |
Dataset containing SAX encoded values (as returned by
|
w |
Word size (motif length in SAX symbols). |
a |
Number of letters in the SAX alphabet. |
sb |
Spatial block size (number of columns per block). |
tb |
Temporal block size (number of rows per block). |
si |
Minimum number of occurrences inside each block (sigma). Default: 3. |
ka |
Minimum number of spatial series with occurrences inside each block (kappa). Default: 3. |
A list of identified motifs. Each motif contains:
Motif sequence in character format.
Matrix indicating which blocks contain this motif.
Data frame with columns s and t giving
the start positions in the original dataset.
D <- STMotif::example_dataset
DS <- NormSAX(STMotif::example_dataset, 5)
stmotifs <- SearchSTMotifs(D, DS, 4, 5, 4, 10, 2, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.