| example_dataset | R Documentation |
A synthetic toy dataset containing 12 spatial-time series, each with 20 time points. Used to demonstrate the motif discovery functions in this package.
example_dataset
A data frame with 20 rows and 12 columns. Each column represents a spatial-time series and each row represents a time point. All values are numeric.
Synthetic data generated for demonstration purposes.
data(example_dataset)
dim(example_dataset)
# [1] 20 12
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.